# Metrics
There are three metrics analyzed from the User Simulator:
1. **User's goal completion rate**: 
   * The percentage of conversations that the chatbot successfully completes the user's goal.
   * Higher the better.
2. **User's goal completion efficiency**: 
   * The average number of turns taken by the chatbot to complete the user's goal. 
   * Lower the better.
3. **Bot's goal completion rate**: 
   * The percentage of conversations that the chatbot successfully completes the builder's goal.
   * Higher the better.
